==> v9.2.0.zip: barker/barker/barker/schemas/cashier_report.py <==
from datetime import date, datetime
from decimal import Decimal
from typing import Dict, List

from pydantic import BaseModel, validator

from . import to_camel
from .user import UserLink


class NameAmount(BaseModel):
    name: str
    amount: Decimal

    class Config:
        anystr_strip_whitespace = True


class SettleOptionSchema(BaseModel):
    def __hash__(self):
        return hash(self.id)

    def __eq__(self, other):
        return self.id == other.id

    id: int
    name: str

    class Config:
        fields = {"id": "id"}
        anystr_strip_whitespace = True


class InfoItem(BaseModel):
    date: datetime
    bill_id: str
    customer: str
    amount: Decimal

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel

    @validator("date", pre=True)
    def parse_date(cls, value):
        if isinstance(value, datetime):
            return value
        return datetime.strptime(value, "%d-%b-%Y %H:%M")


class CashierReport(BaseModel):
    start_date: date
    finish_date: date
    cashier: UserLink
    cashiers: str
    user: UserLink
    amounts: List[NameAmount]
    info: Dict[str, List[InfoItem]]

    class Config:
        fields = {"id_": "id"}
        anystr_strip_whitespace = True
        alias_generator = to_camel
        json_encoders = {datetime: lambda v: v.strftime("%d-%b-%Y %H:%M"), date: lambda v: v.strftime("%d-%b-%Y")}

    @validator("start_date", pre=True)
    def parse_start_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()

    @validator("finish_date", pre=True)
    def parse_finish_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()

==> v10.3.3.zip: barker/barker/barker/schemas/cashier_report.py <==
from datetime import date, datetime
from decimal import Decimal

from pydantic import BaseModel, validator

from . import to_camel
from .user import UserLink


class NameAmount(BaseModel):
    name: str
    amount: Decimal

    class Config:
        anystr_strip_whitespace = True


class SettleOptionSchema(BaseModel):
    def __hash__(self):
        return hash(self.id)

    def __eq__(self, other):
        return self.id == other.id

    id: int
    name: str

    class Config:
        fields = {"id": "id"}
        anystr_strip_whitespace = True


class InfoItem(BaseModel):
    date: datetime
    bill_id: str
    customer: str
    amount: Decimal

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel

    @validator("date", pre=True)
    def parse_date(cls, value):
        if isinstance(value, datetime):
            return value
        return datetime.strptime(value, "%d-%b-%Y %H:%M")


class CashierReport(BaseModel):
    start_date: date
    finish_date: date
    cashier: UserLink
    cashiers: str
    user: UserLink
    amounts: list[NameAmount]
    info: dict[str, list[InfoItem]]

    class Config:
        fields = {"id_": "id"}
        anystr_strip_whitespace = True
        alias_generator = to_camel
        json_encoders = {datetime: lambda v: v.strftime("%d-%b-%Y %H:%M"), date: lambda v: v.strftime("%d-%b-%Y")}

    @validator("start_date", pre=True)
    def parse_start_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()

    @validator("finish_date", pre=True)
    def parse_finish_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()
